#include "seller.h"

Seller::Seller() : Entity() {}

Seller::Seller(const std::string& firstName, const std::string& lastName, int sellerNo,
               int numberOfArticles)
    : Entity()
{
    firstName_ = firstName;
    lastName_ = lastName;
    sellerNo_ = sellerNo;
    numberOfOfferedArticles_ = numberOfArticles;
}

void Seller::setSellerNo(int seller_no) { sellerNo_ = seller_no; }

inline void Seller::setFirstName(const std::string& firstName) { firstName_ = firstName; }

inline void Seller::setLastName(const std::string& lastName) { lastName_ = lastName; }

inline void Seller::setNumberOfOfferedArticles(int number) { numberOfOfferedArticles_ = number; }

int Seller::getNumberOfOfferedArticles() const { return static_cast<int>(articles_.size()); }

void Seller::addArticle(std::shared_ptr<Article> article) { articles_.push_back(article); }

std::string Seller::getFirstName() const { return firstName_; }

std::string Seller::getLastName() const { return lastName_; }

int Seller::getSellerNo() const { return sellerNo_; }

std::vector<std::shared_ptr<Article>> Seller::getArticles(bool onlySold)
{
    std::vector<std::shared_ptr<Article>> articles;
    for (const auto article : articles_) {
        if (onlySold && article->isSold()) {
            articles.push_back(article);
        } else if (!onlySold) {
            articles.push_back(article);
        }
    }
    return articles;
}